import * as i1 from '@angular/common/http';
import { HttpHeaders, HttpClient } from '@angular/common/http';
import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Input, Output, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { map, distinctUntilChanged } from 'rxjs/operators';
import { __decorate } from 'tslib';
import { MatSnackBar, MatSnackBarModule } from '@angular/material/snack-bar';
import { CommonModule } from '@angular/common';

const initialState = {
    ratingInfo: null,
    chips: [],
    progressiveFeedbackData: null,
};
class DpwFeedbackWidgetService {
    constructor(http) {
        this.http = http;
        this.metaData = {};
        this.submitInProgress = false;
        this.userFeedback = new BehaviorSubject(initialState);
        this.userFeedback$ = this.userFeedback.asObservable();
        this.ratingInfo$ = this.userFeedback$.pipe(map((state) => state.ratingInfo), distinctUntilChanged());
        this.headers = null;
        this.apiKey = "wlg9lTshHeXItOPSirQdMTKZTOp6k8vC";
    }
    setConfig(tenantName, tenantId, envType) {
        switch (envType) {
            case "prod":
                this.apiKey = "cyjRHsN7aDA6asOvwQeW0S5yIFpW4zF2";
                break;
            case "staging":
                break;
            default:
                this.baseURL = "https://qa-feedback-service-api.cargoes.com/api/";
                break;
        }
        this.headers = new HttpHeaders({
            "X-DPW-Tenant-Name": tenantName,
            "X-DPW-Tenant-Id": tenantId,
            "X-DPW-ApiKey": this.apiKey,
        });
    }
    get currentState() {
        return this.userFeedback.getValue();
    }
    updateMetaData(data) {
        this.metaData = Object.assign(Object.assign({}, this.metaData), data);
    }
    updateUserFeedback(data) {
        this.userFeedback.next(Object.assign(Object.assign({}, this.currentState), data));
    }
    resetState() {
        this.userFeedback.next(initialState);
    }
    submitFeedback(reqBody) {
        return this.http.post(`${this.baseURL}feedback/users`, reqBody, {
            headers: this.headers,
        });
    }
    isValidHost() {
        return (location.host.includes("cargoes.com") ||
            location.host.includes("localhost"));
    }
}
DpwFeedbackWidgetService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DpwFeedbackWidgetService_Factory() { return new DpwFeedbackWidgetService(i0.ɵɵinject(i1.HttpClient)); }, token: DpwFeedbackWidgetService, providedIn: "root" });
DpwFeedbackWidgetService.decorators = [
    { type: Injectable, args: [{
                providedIn: "root",
            },] }
];
DpwFeedbackWidgetService.ctorParameters = () => [
    { type: HttpClient }
];

const noop = () => { };
const ɵ0 = noop;
function isRequired(requiredType, { size, possibleValues, errorFn = "inputPropErrorHandler", } = {}) {
    return (target, prop) => {
        const NG_ON_ONIT_NAME = "ngOnInit";
        /** ngOnInit might not be implemented by this component */
        const ngOnInitClone = target[NG_ON_ONIT_NAME];
        Object.defineProperty(target, NG_ON_ONIT_NAME, {
            value: function () {
                let errMsg = null;
                if (this[prop] == null) {
                    errMsg =
                        target.constructor.name +
                            `: @Input ${prop} is required, but was not provided`;
                }
                else if (requiredType && typeof this[prop] !== requiredType) {
                    errMsg =
                        target.constructor.name +
                            `: @Input ${prop} is expected to be a ${requiredType}, but ${typeof this[prop]} was provided`;
                }
                else if (size &&
                    typeof this[prop] === "string" &&
                    this[prop].length > size) {
                    errMsg =
                        target.constructor.name +
                            `: @Input '${prop}' can't be more than ${size} characters`;
                }
                else if (possibleValues &&
                    typeof this[prop] === "string" &&
                    !possibleValues.includes(this[prop].toLowerCase())) {
                    errMsg =
                        target.constructor.name +
                            `: @Input '${prop}' is invalid, possible values are ${JSON.stringify(possibleValues)}`;
                }
                errMsg && errorFn && target[errorFn] && target[errorFn].call(target, errMsg);
                // Calling the original ngOnInit with its original context
                (ngOnInitClone || noop).call(this);
            },
        });
    };
}

function isTypeOf(requiredType, { limit, errorFn = "inputPropErrorHandler", } = {}) {
    return (target, prop, newVal) => {
        /** Whether the new value matches the required type */
        let isValidType = true;
        let errMsg = null;
        if (newVal) {
            if (requiredType === "array") {
                isValidType = newVal instanceof Array;
            }
            else {
                isValidType = typeof newVal === requiredType;
            }
            if (!isValidType) {
                errMsg =
                    target.constructor.name +
                        `: @Input '${prop}' is expected to be of type ${requiredType}, but type ${typeof newVal} was provided`;
            }
        }
        if (limit && typeof newVal === "string" && newVal.length > limit) {
            errMsg =
                target.constructor.name +
                    `: @Input '${prop}' can't be more than ${limit} characters`;
        }
        else if (limit && newVal instanceof Array && newVal.length > limit) {
            errMsg =
                target.constructor.name +
                    `: @Input '${prop}' length can't be more than ${limit}`;
        }
        errMsg && errorFn && target[errorFn] && target[errorFn].call(target, errMsg);
    };
}

function validateAgainst(fn) {
    return (target, prop) => {
        let _value = null;
        // Create new property with getter and setter
        Object.defineProperty(target, prop, {
            get() {
                return _value;
            },
            set: function (newVal) {
                _value = newVal;
                fn(target, prop, newVal);
            },
            configurable: true,
            enumerable: true,
        });
    };
}

const RATING_TYPE = {
    GOOD: "GOOD",
    AVERAGE: "AVERAGE",
    BAD: "BAD",
};
const RATING_STYLES = {
    STAR: "star",
    SMILEY: "smiley",
};
const SUPPORTED_RATING_STYLES = [RATING_STYLES.STAR, RATING_STYLES.SMILEY];
const DEFAULT_FEEDBACK_META_DATA = {
    feedbackBtnText: "Submit Feedback",
    showClose: true,
    thankYouHeading: "Thank You!",
    thankYouDescription: "We appriciate your feedback and response. Looking forward to serve you again.",
    thankYouBtnText: "Done",
    badRatingHeader: "What went wrong?",
    averageRatingHeader: "What went well?",
    goodRatingHeader: "What went well?",
    textareaLimit: 250,
    failureHeading: "Something went wrong!",
    failureDescription: "Could not submit feedback, please try submitting again.",
    failureBtnText: "Close"
};
const SMILEY_RATINGS = [
    {
        rating: 1,
        title: "Terrible",
        imgUrl: "assets/images/fw_terribleEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 2,
        title: "Bad",
        imgUrl: "assets/images/fw_badEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 3,
        title: "Okay",
        imgUrl: "assets/images/fw_okayEmoji.svg",
        type: RATING_TYPE.AVERAGE,
    },
    {
        rating: 4,
        title: "Good",
        imgUrl: "assets/images/fw_goodEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
    {
        rating: 5,
        title: "Amazing",
        imgUrl: "assets/images/fw_amazingEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
];
const STAR_RATINGS = [
    {
        rating: 1,
        title: "Very Bad",
        imgUrl: "assets/images/fw_terribleEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 2,
        title: "Bad",
        imgUrl: "assets/images/fw_badEmoji.svg",
        type: RATING_TYPE.BAD,
    },
    {
        rating: 3,
        title: "Okay",
        imgUrl: "assets/images/fw_okayEmoji.svg",
        type: RATING_TYPE.AVERAGE,
    },
    {
        rating: 4,
        title: "Good",
        imgUrl: "assets/images/fw_goodEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
    {
        rating: 5,
        title: "Excellent",
        imgUrl: "assets/images/fw_amazingEmoji.svg",
        type: RATING_TYPE.GOOD,
    },
];

class DpwFeedbackWidgetComponent {
    constructor(fwService, snackBar) {
        this.fwService = fwService;
        this.snackBar = snackBar;
        this.hasError = false;
        this.RATING_STYLES = RATING_STYLES;
        this.onClose = new EventEmitter();
        this.onSuccess = new EventEmitter();
        this.onError = new EventEmitter();
        this.feedbackSubmitted = null;
        this.closeHandler = () => {
            this.onClose.emit();
        };
        this.successHandler = () => {
            this.onSuccess.emit();
        };
        this.onSubmitFeedback = () => {
            if (!this.fwService.isValidHost()) {
                return;
            }
            const { ratingInfo, progressiveFeedbackData, chips } = this.fwService.currentState;
            if (!this.fwService.submitInProgress) {
                this.fwService.submitInProgress = true;
                const data = Object.assign(Object.assign({ userEmail: this.userEmail || "", feedbackWidgetMetadataId: this.feedbackWidgetMetadataId, ratingScore: ratingInfo.rating }, (chips && chips.length ? { progressiveChipsSelected: chips } : null)), { progressiveFeedbackData, additionalParam1: this.trackingParam1, additionalParam2: this.trackingParam2, metadata: this.trackingMetadata && typeof this.trackingMetadata !== "string"
                        ? JSON.stringify(this.trackingMetadata)
                        : this.trackingMetadata });
                this.fwService.submitFeedback(data).subscribe((res) => {
                    this.feedbackSubmitted = true;
                    this.fwService.submitInProgress = false;
                }, (err) => {
                    var _a;
                    this.fwService.submitInProgress = false;
                    this.onError.emit(err);
                    this.snackBar.open((_a = this.fwService.metaData) === null || _a === void 0 ? void 0 : _a.failureDescription, null, {
                        verticalPosition: "top",
                        duration: 4000,
                        panelClass: "fw-warn",
                    });
                });
            }
        };
    }
    ngOnInit() {
        const { heading, description, ratingStyle, feedbackBtnText, showClose, thankYouHeading, thankYouDescription, thankYouBtnText, enableProgressive, progressiveChips, badRatingHeader, averageRatingHeader, goodRatingHeader, isLoggedIn, textareaLimit, failureHeading, failureDescription, failureBtnText, closeHandler, onSubmitFeedback, successHandler, } = this;
        this.fwService.updateMetaData({
            header: heading,
            subHeader: description,
            ratingStyle,
            feedbackBtnText: feedbackBtnText || DEFAULT_FEEDBACK_META_DATA.feedbackBtnText,
            showClose: showClose || DEFAULT_FEEDBACK_META_DATA.showClose,
            thankYouHeading,
            thankYouDescription,
            thankYouBtnText: thankYouBtnText || DEFAULT_FEEDBACK_META_DATA.thankYouBtnText,
            enableProgressive: isLoggedIn && enableProgressive,
            progressiveChips,
            badRatingHeader: badRatingHeader || DEFAULT_FEEDBACK_META_DATA.badRatingHeader,
            averageRatingHeader: averageRatingHeader || DEFAULT_FEEDBACK_META_DATA.averageRatingHeader,
            goodRatingHeader: goodRatingHeader || DEFAULT_FEEDBACK_META_DATA.goodRatingHeader,
            textareaLimit: textareaLimit || DEFAULT_FEEDBACK_META_DATA.textareaLimit,
            failureHeading: failureHeading || DEFAULT_FEEDBACK_META_DATA.failureHeading,
            failureDescription: failureDescription || DEFAULT_FEEDBACK_META_DATA.failureDescription,
            failureBtnText: failureBtnText || DEFAULT_FEEDBACK_META_DATA.failureBtnText,
            closeHandler,
            onSubmitFeedback,
            successHandler,
        });
        this.fwService.setConfig(this.tenantName, this.tenantId, this.environmentType);
    }
    inputPropErrorHandler(errMsg) {
        this.hasError = true;
        throw new Error(errMsg);
    }
    ngOnDestroy() {
        this.fwService.resetState();
    }
}
DpwFeedbackWidgetComponent.decorators = [
    { type: Component, args: [{
                selector: "dpw-feedback-widget",
                template: "<div class=\"feedback-widget-container\" *ngIf=\"!hasError\">\n  <div\n    class=\"fw-dialog-container\" [ngClass]=\"ratingStyle?.toLowerCase()\"\n    [style.width]=\"width\"\n    [style.height]=\"height\"\n    *ngIf=\"feedbackSubmitted === null; else fbDone\"\n  >\n    <lib-feedback-widget-header></lib-feedback-widget-header>\n    <div class=\"fw-dialog-content\">\n      <div class=\"fw-sub-header\">{{ description }}</div>\n      <ng-container [ngSwitch]=\"ratingStyle?.toLowerCase()\">\n        <ng-container *ngSwitchCase=\"RATING_STYLES.STAR\">\n          <app-star-feedback-widget></app-star-feedback-widget>\n        </ng-container>\n        <ng-container *ngSwitchCase=\"RATING_STYLES.SMILEY\">\n          <app-smiley-feedback-widget></app-smiley-feedback-widget>\n        </ng-container>\n      </ng-container>\n      <lib-progressive-rating\n        *ngIf=\"\n          fwService.metaData.enableProgressive &&\n          fwService.currentState.ratingInfo\n        \"\n      ></lib-progressive-rating>\n    </div>\n    <lib-feedback-widget-footer\n      [fullWidth]=\"ratingStyle?.toLowerCase() === RATING_STYLES.STAR\"\n      [disabled]=\"!fwService.currentState.ratingInfo\"\n    ></lib-feedback-widget-footer>\n  </div>\n  <ng-template #fbDone>\n    <div class=\"fw-dialog-container thankyou\" *ngIf=\"feedbackSubmitted; else error\">\n      <lib-feedback-widget-thankyou></lib-feedback-widget-thankyou>\n    </div>\n    <ng-template #error>\n      <div class=\"fw-dialog-container error\">\n        <lib-feedback-widget-error></lib-feedback-widget-error>\n      </div>\n    </ng-template>\n  </ng-template>\n</div>\n",
                styles: [":host .feedback-widget-container{position:fixed;z-index:99999999;background:rgba(0,0,0,.5);width:100%;height:100%;top:0;left:0;bottom:0;right:0}:host .feedback-widget-container .fw-dialog-container{background:#ffffff;border-radius:3px 3px 0 0;box-sizing:border-box;overflow:auto;position:absolute;left:50%;top:50%;transform:translate(-50%,-50%);max-width:90vw;max-height:90vh}:host .feedback-widget-container .fw-dialog-container.star{width:500px}:host .feedback-widget-container .fw-dialog-container.smiley{width:650px}:host .feedback-widget-container .fw-dialog-container.thankyou,:host .feedback-widget-container .fw-dialog-container.error{width:500px}:host .feedback-widget-container .fw-dialog-container .fw-sub-header{font-weight:400;font-size:15px}:host ::ng-deep .fw-header-container,:host ::ng-deep .fw-footer-container,:host ::ng-deep .fw-dialog-content{padding-left:40px;padding-right:40px}:host ::ng-deep .fw-header-container{padding-top:40px;padding-bottom:20px}:host ::ng-deep .fw-footer-container{padding-bottom:40px}\n"]
            },] }
];
DpwFeedbackWidgetComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService },
    { type: MatSnackBar }
];
DpwFeedbackWidgetComponent.propDecorators = {
    width: [{ type: Input }],
    height: [{ type: Input }],
    tenantId: [{ type: Input }],
    tenantName: [{ type: Input }],
    heading: [{ type: Input }],
    description: [{ type: Input }],
    ratingStyle: [{ type: Input }],
    userEmail: [{ type: Input }],
    isLoggedIn: [{ type: Input }],
    feedbackBtnText: [{ type: Input }],
    showClose: [{ type: Input }],
    thankYouHeading: [{ type: Input }],
    thankYouDescription: [{ type: Input }],
    thankYouBtnText: [{ type: Input }],
    enableProgressive: [{ type: Input }],
    progressiveChips: [{ type: Input }],
    badRatingHeader: [{ type: Input }],
    averageRatingHeader: [{ type: Input }],
    goodRatingHeader: [{ type: Input }],
    onClose: [{ type: Output }],
    onSuccess: [{ type: Output }],
    onError: [{ type: Output }],
    textareaLimit: [{ type: Input }],
    failureHeading: [{ type: Input }],
    failureDescription: [{ type: Input }],
    failureBtnText: [{ type: Input }],
    feedbackWidgetMetadataId: [{ type: Input }],
    trackingParam1: [{ type: Input }],
    trackingParam2: [{ type: Input }],
    trackingMetadata: [{ type: Input }],
    environmentType: [{ type: Input }]
};
__decorate([
    validateAgainst(isTypeOf("boolean"))
], DpwFeedbackWidgetComponent.prototype, "hasError", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "width", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "height", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "tenantId", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "tenantName", void 0);
__decorate([
    isRequired("string", { size: 100 })
], DpwFeedbackWidgetComponent.prototype, "heading", void 0);
__decorate([
    isRequired("string", { size: 200 })
], DpwFeedbackWidgetComponent.prototype, "description", void 0);
__decorate([
    isRequired("string", {
        possibleValues: SUPPORTED_RATING_STYLES,
    })
], DpwFeedbackWidgetComponent.prototype, "ratingStyle", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "userEmail", void 0);
__decorate([
    isRequired("boolean")
], DpwFeedbackWidgetComponent.prototype, "isLoggedIn", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "feedbackBtnText", void 0);
__decorate([
    validateAgainst(isTypeOf("boolean"))
], DpwFeedbackWidgetComponent.prototype, "showClose", void 0);
__decorate([
    isRequired("string", { size: 100 })
], DpwFeedbackWidgetComponent.prototype, "thankYouHeading", void 0);
__decorate([
    isRequired("string", { size: 200 })
], DpwFeedbackWidgetComponent.prototype, "thankYouDescription", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "thankYouBtnText", void 0);
__decorate([
    validateAgainst(isTypeOf("boolean"))
], DpwFeedbackWidgetComponent.prototype, "enableProgressive", void 0);
__decorate([
    validateAgainst(isTypeOf("array", { limit: 4 }))
], DpwFeedbackWidgetComponent.prototype, "progressiveChips", void 0);
__decorate([
    validateAgainst(isTypeOf("string", { limit: 50 }))
], DpwFeedbackWidgetComponent.prototype, "badRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("string", { limit: 50 }))
], DpwFeedbackWidgetComponent.prototype, "averageRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("string", { limit: 50 }))
], DpwFeedbackWidgetComponent.prototype, "goodRatingHeader", void 0);
__decorate([
    validateAgainst(isTypeOf("number"))
], DpwFeedbackWidgetComponent.prototype, "textareaLimit", void 0);
__decorate([
    validateAgainst(isTypeOf("string", { limit: 100 }))
], DpwFeedbackWidgetComponent.prototype, "failureHeading", void 0);
__decorate([
    validateAgainst(isTypeOf("string", { limit: 200 }))
], DpwFeedbackWidgetComponent.prototype, "failureDescription", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "failureBtnText", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "trackingParam1", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "trackingParam2", void 0);
__decorate([
    validateAgainst(isTypeOf("string"))
], DpwFeedbackWidgetComponent.prototype, "environmentType", void 0);

class StarFeedbackWidgetComponent {
    constructor(fwService) {
        this.fwService = fwService;
        this.ratingArr = STAR_RATINGS;
        this.starIcon = "assets/images/fw_starIcon.svg";
        this.starIconYellow = "assets/images/fw_starIconYellow.svg";
    }
    ngOnInit() { }
    onSelect(ratingInfo) {
        this.fwService.updateUserFeedback({ ratingInfo });
    }
}
StarFeedbackWidgetComponent.decorators = [
    { type: Component, args: [{
                selector: "app-star-feedback-widget",
                template: "<div class=\"fw-rating-container\">\n    <div class=\"fw-rating\" *ngFor=\"let item of ratingArr\" (click)=\"onSelect(item)\">\n        <img [src]=\"fwService.currentState.ratingInfo?.rating >= item.rating ? starIconYellow : starIcon\" />\n    </div>\n</div>\n<div class=\"fw-rating-info\" [hidden]=\"!fwService.currentState.ratingInfo\">\n    <img [src]=\"fwService.currentState.ratingInfo?.imgUrl\" />\n    <span [ngClass]=\"{'fw-green': fwService.currentState.ratingInfo?.rating > 2, 'fw-red': fwService.currentState.ratingInfo?.rating < 3}\">{{ fwService.currentState.ratingInfo?.title }}</span>\n</div>",
                styles: [":host .fw-rating-container{display:flex;justify-content:space-between;margin:40px 0}:host .fw-rating-container .fw-rating{display:flex;flex-direction:column;align-items:center;justify-content:center;cursor:pointer}:host .fw-rating-container .fw-rating img{width:40px;height:38px}:host .fw-rating-info{display:flex!important;align-items:center;justify-content:center;margin:40px 0}:host .fw-rating-info span{margin-left:10px;font-weight:700;font-size:15px;line-height:21px}:host .fw-rating-info span.fw-green{color:#5fb25c}:host .fw-rating-info span.fw-red{color:#e53935}\n"]
            },] }
];
StarFeedbackWidgetComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class SmileyFeedbackWidgetComponent {
    constructor(fwService) {
        this.fwService = fwService;
        this.ratingArr = SMILEY_RATINGS;
    }
    ngOnInit() { }
    onSelect(ratingInfo) {
        this.fwService.updateUserFeedback({ ratingInfo });
    }
}
SmileyFeedbackWidgetComponent.decorators = [
    { type: Component, args: [{
                selector: "app-smiley-feedback-widget",
                template: "<div class=\"fw-rating-container\">\n    <div class=\"fw-rating\" *ngFor=\"let item of ratingArr\" [ngClass]=\"{'fw-active': fwService.currentState.ratingInfo?.title === item.title }\" (click)=\"onSelect(item)\">\n        <img [src]=\"item.imgUrl\" />\n        <label>{{item.title}}</label>\n    </div>\n</div>",
                styles: [":host .fw-rating-container{display:flex;justify-content:space-between;margin:40px 0}:host .fw-rating-container .fw-rating{border-radius:3px;text-align:center;width:100px;height:100px;display:flex;flex-direction:column;align-items:center;justify-content:center;cursor:pointer;box-sizing:border-box}:host .fw-rating-container .fw-rating img{width:30px;height:30px}:host .fw-rating-container .fw-rating label{margin-top:10px;cursor:pointer}:host .fw-rating-container .fw-rating.fw-active,:host .fw-rating-container .fw-rating:hover{background:#e3f2fd;border:1px solid #0b78d0}\n"]
            },] }
];
SmileyFeedbackWidgetComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class FeedbackWidgetHeaderComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
}
FeedbackWidgetHeaderComponent.decorators = [
    { type: Component, args: [{
                selector: "lib-feedback-widget-header",
                template: "<div class=\"fw-header-container\">\n  <div class=\"fw-header\">{{ fwService.metaData.header }}</div>\n  <img *ngIf=\"fwService.metaData.showClose\" class=\"fw-close-icon\" (click)=\"fwService.metaData.closeHandler()\" src=\"assets/images/fw_close_icon.svg\" />\n</div>\n",
                styles: [":host .fw-header-container{position:sticky;top:0;background-color:#fff}:host .fw-header-container .fw-header{font-weight:700;font-size:24px}:host .fw-header-container .fw-close-icon{position:absolute;top:10px;right:10px;width:21px;height:21px;cursor:pointer}\n"]
            },] }
];
FeedbackWidgetHeaderComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class FeedbackWidgetFooterComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
}
FeedbackWidgetFooterComponent.decorators = [
    { type: Component, args: [{
                selector: "lib-feedback-widget-footer",
                template: "<div class=\"fw-footer-container\">\n  <button\n    class=\"fw-submit-btn\"\n    [ngClass]=\"{\n      'fw-fullWidth': fullWidth,\n      'fw-disable': disabled,\n      'fw-active': !disabled,\n      'fw-inProgress': fwService.submitInProgress\n    }\"\n    (click)=\"!disabled && fwService.metaData.onSubmitFeedback()\"\n  >\n    {{ fwService.metaData.feedbackBtnText }}\n  </button>\n</div>\n",
                styles: [":host .fw-footer-container{display:flex;align-items:center;justify-content:flex-end}:host .fw-footer-container .fw-submit-btn{width:200px;height:40px;border-radius:3px;font-weight:700;font-size:12px;line-height:21px;text-align:center;text-transform:uppercase;color:#fff;cursor:pointer}:host .fw-footer-container .fw-submit-btn.fw-active{background:#0b78d0;border:3px solid #0b78d0}:host .fw-footer-container .fw-submit-btn.fw-disable{background:#bebec1;border:3px solid #bebec1;cursor:not-allowed}:host .fw-footer-container .fw-submit-btn.fw-inProgress{cursor:progress}:host .fw-footer-container .fw-submit-btn.fw-fullWidth{width:100%}\n"]
            },] }
];
FeedbackWidgetFooterComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];
FeedbackWidgetFooterComponent.propDecorators = {
    fullWidth: [{ type: Input }],
    disabled: [{ type: Input }]
};

class FeedbackWidgetThankyouComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
    onDone() {
        this.fwService.metaData.closeHandler();
        this.fwService.metaData.successHandler();
    }
}
FeedbackWidgetThankyouComponent.decorators = [
    { type: Component, args: [{
                selector: "lib-feedback-widget-thankyou",
                template: "<div class=\"fw-header-container\">\n  <div class=\"fw-header\">\n    <img src=\"assets/images/fw_greenTick.svg\" />\n    <span>{{ fwService.metaData.thankYouHeading }}</span>\n  </div>\n  <img\n    *ngIf=\"fwService.metaData.showClose\"\n    class=\"fw-close-icon\"\n    (click)=\"fwService.metaData.closeHandler()\"\n    src=\"assets/images/fw_close_icon.svg\"\n  />\n</div>\n<div class=\"fw-dialog-content\">\n  <div class=\"fw-sub-header\">{{ fwService.metaData.thankYouDescription }}</div>\n</div>\n<div class=\"fw-footer-container\">\n  <button class=\"fw-submit-btn fw-active\" (click)=\"onDone()\">\n    {{ fwService.metaData.thankYouBtnText }}\n  </button>\n</div>\n",
                styles: [":host .fw-header-container{position:sticky;top:0;background-color:#fff}:host .fw-header-container .fw-header{font-weight:700;font-size:24px;color:#5fb25c;display:flex;align-items:flex-start;line-height:33px}:host .fw-header-container .fw-header img{position:relative;top:5px;margin-right:15px}:host .fw-header-container .fw-close-icon{position:absolute;top:10px;right:10px;width:21px;height:21px;cursor:pointer}:host .fw-sub-header{font-weight:400;font-size:15px}:host .fw-footer-container{display:flex;align-items:center;justify-content:flex-end;margin-top:40px}:host .fw-footer-container .fw-submit-btn{width:125px;height:40px;border-radius:3px;font-weight:700;font-size:12px;line-height:21px;text-align:center;text-transform:uppercase;color:#fff;cursor:pointer}:host .fw-footer-container .fw-submit-btn.fw-active{background:#0b78d0;border:3px solid #0b78d0}\n"]
            },] }
];
FeedbackWidgetThankyouComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class ProgressiveRatingComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
    onSelectChip(item) {
        const chips = this.fwService.currentState.chips;
        const index = chips.indexOf(item);
        let newChips = [];
        if (index === -1) {
            newChips = [...chips, item];
        }
        else {
            newChips = chips.filter((chip) => chip !== item);
        }
        this.fwService.updateUserFeedback({ chips: newChips });
    }
    getHeader() {
        const type = this.fwService.currentState.ratingInfo.type;
        const { badRatingHeader, averageRatingHeader, goodRatingHeader } = this.fwService.metaData;
        switch (type) {
            case RATING_TYPE.GOOD:
                return goodRatingHeader;
            case RATING_TYPE.AVERAGE:
                return averageRatingHeader;
            case RATING_TYPE.BAD:
                return badRatingHeader;
            default:
                return "";
        }
    }
    onFeedbackText(progressiveFeedbackData) {
        this.fwService.updateUserFeedback({ progressiveFeedbackData });
    }
}
ProgressiveRatingComponent.decorators = [
    { type: Component, args: [{
                selector: "lib-progressive-rating",
                template: "<div class=\"fw-progressive-rating\">\n  <p class=\"fw-header\">{{ getHeader() }}</p>\n  <div\n    class=\"fw-chips-container\"\n    *ngIf=\"fwService.metaData?.progressiveChips?.length; else textArea\"\n  >\n    <div\n      class=\"fw-chip-item\"\n      [ngClass]=\"{ 'fw-active': fwService.currentState.chips.includes(item) }\"\n      *ngFor=\"let item of fwService.metaData.progressiveChips\"\n      (click)=\"onSelectChip(item)\"\n    >\n      {{ item }}\n    </div>\n  </div>\n  <ng-template #textArea>\n    <div class=\"fw-textarea\">\n      <textarea\n        rows=\"4\"\n        cols=\"100\"\n        placeholder=\"Tell us more (optional)\"\n        [maxLength]=\"fwService.metaData.textareaLimit\"\n        [value]=\"fwService.currentState.progressiveFeedbackData\"\n        (change)=\"onFeedbackText($event.target.value)\"\n      ></textarea>\n    </div>\n  </ng-template>\n</div>\n",
                styles: [":host .fw-progressive-rating{margin:40px 0}:host .fw-progressive-rating .fw-header{font-weight:700;font-size:18px;line-height:24px;margin:0}:host .fw-progressive-rating .fw-chips-container{display:flex;flex-wrap:wrap;justify-content:space-between}:host .fw-progressive-rating .fw-chip-item{padding:15px 20px;font-size:15px;font-weight:700;border:1px solid #6a6a6d;border-radius:3px;cursor:pointer;width:calc(50% - 7.5px);box-sizing:border-box;margin-top:15px;align-items:center;display:flex}:host .fw-progressive-rating .fw-chip-item.fw-active{background:#e3f2fd;color:#007ba8;border:1px solid #0b78d0}:host .fw-progressive-rating .fw-textarea{display:flex;margin-top:20px}:host .fw-progressive-rating .fw-textarea textarea{border:1px solid #6a6a6d;border-radius:3px;padding:10px;resize:none}\n"]
            },] }
];
ProgressiveRatingComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class FeedbackWidgetErrorComponent {
    constructor(fwService) {
        this.fwService = fwService;
    }
    ngOnInit() { }
    onDone() {
        this.fwService.metaData.closeHandler();
    }
}
FeedbackWidgetErrorComponent.decorators = [
    { type: Component, args: [{
                selector: 'lib-feedback-widget-error',
                template: "<div class=\"fw-header-container\">\n    <div class=\"fw-header\">\n      <!-- <img src=\"assets/images/fw_greenTick.svg\" /> -->\n      {{ fwService.metaData.failureHeading }}\n    </div>\n    <img\n      *ngIf=\"fwService.metaData.showClose\"\n      class=\"fw-close-icon\"\n      (click)=\"fwService.metaData.closeHandler()\"\n      src=\"assets/images/fw_close_icon.svg\"\n    />\n  </div>\n  <div class=\"fw-dialog-content\">\n    <div class=\"fw-sub-header\">{{ fwService.metaData.failureDescription }}</div>\n  </div>\n  <div class=\"fw-footer-container\">\n    <button class=\"fw-submit-btn fw-active\" (click)=\"onDone()\">\n      {{ fwService.metaData.failureBtnText }}\n    </button>\n  </div>\n  ",
                styles: [":host .fw-header-container{position:sticky;top:0;background-color:#fff}:host .fw-header-container .fw-header{font-weight:700;font-size:24px;display:flex;align-items:center}:host .fw-header-container .fw-header img{margin-right:15px}:host .fw-header-container .fw-close-icon{position:absolute;top:10px;right:10px;width:21px;height:21px;cursor:pointer}:host .fw-sub-header{font-weight:400;font-size:15px}:host .fw-footer-container{display:flex;align-items:center;justify-content:flex-end;margin-top:40px}:host .fw-footer-container .fw-submit-btn{width:125px;height:40px;border-radius:3px;font-weight:700;font-size:12px;line-height:21px;text-align:center;text-transform:uppercase;color:#fff;cursor:pointer}:host .fw-footer-container .fw-submit-btn.fw-active{background:#0b78d0;border:3px solid #0b78d0}\n"]
            },] }
];
FeedbackWidgetErrorComponent.ctorParameters = () => [
    { type: DpwFeedbackWidgetService }
];

class MaterialModule {
}
MaterialModule.decorators = [
    { type: NgModule, args: [{
                imports: [],
                exports: [MatSnackBarModule],
            },] }
];
/**  Copyright 2020 Google LLC. All Rights Reserved.
    Use of this source code is governed by an MIT-style license that
    can be found in the LICENSE file at http://angular.io/license */

class DpwFeedbackWidgetModule {
}
DpwFeedbackWidgetModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    DpwFeedbackWidgetComponent,
                    StarFeedbackWidgetComponent,
                    SmileyFeedbackWidgetComponent,
                    FeedbackWidgetHeaderComponent,
                    FeedbackWidgetFooterComponent,
                    FeedbackWidgetThankyouComponent,
                    ProgressiveRatingComponent,
                    FeedbackWidgetErrorComponent,
                ],
                imports: [CommonModule, MaterialModule],
                exports: [DpwFeedbackWidgetComponent],
            },] }
];

/*
 * Public API Surface of dpw-feedback-widget
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DpwFeedbackWidgetComponent, DpwFeedbackWidgetModule, DpwFeedbackWidgetService, RATING_STYLES as ɵa, SUPPORTED_RATING_STYLES as ɵb, StarFeedbackWidgetComponent as ɵc, SmileyFeedbackWidgetComponent as ɵd, FeedbackWidgetHeaderComponent as ɵe, FeedbackWidgetFooterComponent as ɵf, FeedbackWidgetThankyouComponent as ɵg, ProgressiveRatingComponent as ɵh, FeedbackWidgetErrorComponent as ɵi, MaterialModule as ɵj };
//# sourceMappingURL=dpw-feedback-widget.js.map
